@@ -8,7 +8,10 @@ test_that(
     skip_on_travis()
 
     set.seed(27599)
-    test.cross <- qtl::sim.cross(map = qtl::sim.map(len = rep(40, 3), n.mar = 10, eq.spacing = FALSE, include.x = FALSE),
+    test.cross <- qtl::sim.cross(map = qtl::sim.map(len = rep(40, 3),
+                                                    n.mar = 10,
+                                                    eq.spacing = FALSE,
+                                                    include.x = FALSE),
                                  n.ind = 500)
     test.cross[['pheno']][['sex']] <- sample(x = c(0, 1),
                                              size = qtl::nind(test.cross),
@@ -19,7 +22,8 @@ test_that(
 
     test.cross <- qtl::calc.genoprob(cross = test.cross, step = 3)
 
-    test.cross[['pheno']][['phenotype']] <-rnorm(n = qtl::nind(test.cross), mean = 0.5*test.cross$geno$`1`$data[,4])
+    test.cross[['pheno']][['phenotype']] <-rnorm(n = qtl::nind(test.cross),
+                                                 mean = 0.5*test.cross$geno$`1`$data[,4])
 
 
     sov <- vqtl::scanonevar(cross = test.cross,
@@ -33,6 +37,10 @@ test_that(
     expect_true(object = all(bs$bootstrap_maxes >= 0))
     expect_true(object = all(bs$bootstrap_maxes <= 40))
 
+    expect_equal(object = length(bs_multicore$bootstrap_maxes), expected = 20)
+    expect_true(object = all(bs_multicore$bootstrap_maxes >= 0))
+    expect_true(object = all(bs_multicore$bootstrap_maxes <= 40))
+
 
     bs <- vqtl::scanonevar.boot(sov = sov, n.resamples = 20, chr = 1, qtl_type = 'vQTL')
 
